# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["LegalForm"]


class LegalForm(BaseModel):
    iso20275_legal_form_code: Optional[str] = FieldInfo(alias="iso20275LegalFormCode", default=None)

    normalized: Optional[str] = None

    original: Optional[str] = None
